#include "imagecontainer.h"
namespace Spotify
{
    ImageContainer::ImageContainer(QObject* parent)
        : QObject(parent)
    {
    }

    void ImageContainer::setImage( QImage image )
    {
        m_image = image;
        emit loaded();
    }

    QImage ImageContainer::getImage() const
    {
        return m_image;
    }
} // namespace Spotify
